fastDist: A fast distance algorithm for two matrices written in C++

View source: R/RcppExports.R

fastDistR Documentation

A fast distance algorithm for two matrices written in C++

Description

A fast distance algorithm for two matrices written in C++

Usage

fastDist(X,Y,method)

Arguments

X

a matrix

Y

a matrix

method

a string with possible values "euclid", "cor", "cosine"

Value

a distance matrix

Author(s)

Antoine Stevens and Leonardo Ramirez-Lopez


prospectr documentation built on May 31, 2026, 9:07 a.m.