fastDistV: A fast distance algorithm for a matrix and a vector written...

View source: R/RcppExports.R

fastDistVR Documentation

A fast distance algorithm for a matrix and a vector written in C++

Description

A fast distance algorithm for a matrix and a vector written in C++

Usage

fastDistV(X,Y,method)

Arguments

X

a matrix

Y

a vector

method

a string with possible values "euclid", "cor", "cosine"

Value

a distance vector

Author(s)

Antoine Stevens and Leonardo Ramirez-Lopez


prospectr documentation built on Aug. 25, 2026, 9:08 a.m.