get_nircal_description: get the description of the spectra in the nircal file

View source: R/read_nircal.R

get_nircal_descriptionR Documentation

get the description of the spectra in the nircal file

Description

internal

Usage

get_nircal_description(x, begin_s, spcinfo, comment_s, comment_f, n)

prospectr documentation built on May 31, 2026, 9:07 a.m.