get_nircal_indices: get the positions of relevant data witihi the nircal file

View source: R/read_nircal.R

get_nircal_indicesR Documentation

get the positions of relevant data witihi the nircal file

Description

internal

Usage

get_nircal_indices(x)

prospectr documentation built on May 31, 2026, 9:07 a.m.