Skip to contents

Stable lifecycle

Misc functions for spectral data

This package implements a number of functions useful for pre-processing spectral data well as for selecting representative samples/spectra. The functions included here are particularly useful in Near-Infrared and Infrared Spectroscopy applications.

Details

This is the version 0.2.9 – proxy of the package. The main functionality is listed here.

Currently, the following preprocessing functions are available:

For the selection of representative samples/observations for calibrating spectral models the following functions ca be used:

Other useful functions are also available:

Author

Maintainer: Leonardo Ramirez-Lopez ramirez.lopez.leo@gmail.com

Authors:

  • Antoine Stevens (ORCID)

  • Leonardo Ramirez-Lopez (ORCID)