Read single or multiple binary and ASCII files acquired with an ASD FieldSpec Pro (ASDi, Boulder, CO) spectroradiometer
Value
if out_format = 'matrix', reflectance values of the input file(s) in a single matrix.
if out_format = 'list', a list of the input file(s) data consisting of a list with components:
Name: name of the file importeddatetime: date and time of acquisition inPOSIXctformatheader: list with information from the header fileradiance: if applicable, a numeric vector of radiance valuesreference: if applicable, a numeric vector of radiance values of the white referencereflectance: numeric vector of reflectance valueswavelength: numeric vector of the band positions
Note
There is a R port of the importasd.m function from the
‘FSFPostProcessing’ Matlab toolbox by Iain Robinson
(University of Edinburgh), which is based on some Java code provided
by Andreas Hunei (University of Zurich).
It seems that ASD file format has changed quite a lot with file versions. The function will possibly not work as expected for all versions. Please report any bugs to the package maintainer.