This function normalizes each row of an input matrix by subtracting each row by its mean and dividing it by its standard deviation
Details
SNV is simple way for normalizing spectral data that intends to correct for light scatter. It operates row-wise:
\[SNV_i = \frac{x_i - \bar{x}_i}{s_i}\]
where \(x_i\) is the signal of the \(i\)th observation, \(\bar{x}_i\) is its mean and \(s_i\) its standard deviation.
References
Barnes RJ, Dhanoa MS, Lister SJ. 1989. Standard normal variate transformation and de-trending of near-infrared diffuse reflectance spectra. Applied spectroscopy, 43(5): 772-777.